SaveMode: SaveMode

SaveModeR Documentation

SaveMode

Description

The following save modes are supported:

  • OVERWRITE: Overwrite any existing data.

  • APPEND: Append the new data to the existing data.

  • IGNORE: Only save the data if the file does not already exist.

  • ERROR: Raise an error if the file already exists.

  • MERGE: Merge the new data with the existing data based on resource ID.

Usage

SaveMode

pathling documentation built on June 3, 2026, 9:08 a.m.