ds_read: Get data for a resource type from a data source

View source: R/datasource.R

ds_readR Documentation

Get data for a resource type from a data source

Description

Get data for a resource type from a data source

Usage

ds_read(ds, resource_code)

Arguments

ds

The DataSource object.

resource_code

A string representing the type of FHIR resource to read data from.

Value

A Spark DataFrame containing the data for the given resource type.

Examples

## Not run: 
data_source <- pc %>% pathling_read_ndjson(pathling_examples("ndjson"))
data_source %>%
  ds_read("Patient") %>%
  sparklyr::sdf_nrow()
data_source %>%
  ds_read("Condition") %>%
  sparklyr::sdf_nrow()

## End(Not run)

pathling documentation built on June 3, 2026, 9:08 a.m.