ds_write_delta: Write FHIR data to Delta files

View source: R/datasource.R

ds_write_deltaR Documentation

Write FHIR data to Delta files

Description

Writes the data from a data source to a directory of Delta files.

Usage

ds_write_delta(ds, path, save_mode = SaveMode$OVERWRITE)

Arguments

ds

The DataSource object.

path

The URI of the directory to write the files to.

save_mode

The save mode to use when writing the data - "overwrite" will overwrite any existing data, "merge" will merge the new data with the existing data based on resource ID.

Value

A list with element file_infos, containing a list of files created. Each file has fhir_resource_type and absolute_url.

See Also

Pathling documentation - Writing Delta

SaveMode

Other data sink functions: ds_write_ndjson(), ds_write_parquet(), ds_write_tables()

Examples


pc <- pathling_connect()
data_source <- pc %>% pathling_read_ndjson(pathling_examples("ndjson"))

# Write the data to a directory of Delta files.
data_source %>% ds_write_delta(file.path(tempdir(), "delta"), save_mode = SaveMode$OVERWRITE)

pathling_disconnect(pc)


pathling documentation built on June 3, 2026, 9:08 a.m.