ds_write_parquet: Write FHIR data to Parquet files

View source: R/datasource.R

ds_write_parquetR Documentation

Write FHIR data to Parquet files

Description

Writes the data from a data source to a directory of Parquet files.

Usage

ds_write_parquet(ds, path, save_mode = SaveMode$ERROR)

Arguments

ds

The DataSource object.

path

The URI of the directory to write the files to.

save_mode

The save mode to use when writing the data.

Value

A list with element file_infos, containing a list of files created. Each file has fhir_resource_type and absolute_url.

See Also

Pathling documentation - Writing Parquet

Other data sink functions: ds_write_delta(), ds_write_ndjson(), ds_write_tables()

Examples


pc <- pathling_connect()
data_source <- pc %>% pathling_read_ndjson(pathling_examples("ndjson"))

# Write the data to a directory of Parquet files.
data_source %>% ds_write_parquet(file.path(tempdir(), "parquet"))

pathling_disconnect(pc)


pathling documentation built on June 3, 2026, 9:08 a.m.