pathling_encode_bundle: Encode FHIR Bundles to a dataframe

View source: R/encoding.R

pathling_encode_bundleR Documentation

Encode FHIR Bundles to a dataframe

Description

Takes a dataframe with string representations of FHIR bundles in the given column and outputs a dataframe of encoded resources.

Usage

pathling_encode_bundle(pc, df, resource_name, input_type = NULL, column = NULL)

Arguments

pc

A Pathling context object.

df

A Spark DataFrame containing the bundles with the resources to encode.

resource_name

The name of the FHIR resource to extract (Condition, Observation, etc.).

input_type

The MIME type of the input string encoding. Defaults to 'application/fhir+json'.

column

The column in which the resources to encode are stored. If 'NULL', then the input DataFrame is assumed to have one column of type string.

Value

A Spark DataFrame containing the given type of resources encoded into Spark columns.

See Also

Other encoding functions: pathling_encode()

Examples


pc <- pathling_connect()
json_resources_df <- pathling_spark(pc) %>%
  sparklyr::spark_read_text(
    path = system.file("extdata", "bundle-xml", package = "pathling"),
    whole = TRUE
  )
pc %>% pathling_encode_bundle(json_resources_df, "Condition",
  input_type = MimeType$FHIR_XML, column = "contents"
)
pathling_disconnect(pc)


pathling documentation built on June 3, 2026, 9:08 a.m.