to_array: Convert a vector to a SQL array literal

View source: R/udfs.R

to_arrayR Documentation

Convert a vector to a SQL array literal

Description

Converts a vector to an expression with the corresponding SQL array literal.

Usage

to_array(value)

Arguments

value

A character or numeric vector to be converted

Value

The quosure with the SQL array literal that can be used in dplyr::mutate.


pathling documentation built on June 3, 2026, 9:08 a.m.