tx_display: Get the display text for codings

View source: R/udfs.R

tx_displayR Documentation

Get the display text for codings

Description

Takes a Coding column as its input. Returns a Column that contains the canonical display name associated with the given code.

Usage

tx_display(coding, accept_language = NULL)

Arguments

coding

A Column containing a struct representation of a Coding.

accept_language

The optional language preferences for the returned display name. Overrides the parameter 'accept_language' in pathling_connect.

Value

A Column containing the result of the operation (String).

See Also

Pathling documentation - Multi-language support

Other terminology functions: tx_member_of(), tx_property_of(), tx_subsumed_by(), tx_subsumes(), tx_translate()

Examples

## Not run: 
# Get the display name of the first coding of the Condition resource, with the default language.
pc %>%
  pathling_example_resource("Condition") %>%
  sparklyr::mutate(
    id,
    display = !!tx_display(code[["coding"]][[0]]),
    .keep = "none"
  )

## End(Not run)

pathling documentation built on June 3, 2026, 9:08 a.m.