| ds_read | R Documentation |
Get data for a resource type from a data source
ds_read(ds, resource_code)
ds |
The DataSource object. |
resource_code |
A string representing the type of FHIR resource to read data from. |
A Spark DataFrame containing the data for the given resource type.
## Not run:
data_source <- pc %>% pathling_read_ndjson(pathling_examples("ndjson"))
data_source %>%
ds_read("Patient") %>%
sparklyr::sdf_nrow()
data_source %>%
ds_read("Condition") %>%
sparklyr::sdf_nrow()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.