| pathling_encode_bundle | R Documentation |
Takes a dataframe with string representations of FHIR bundles in the given column and outputs a dataframe of encoded resources.
pathling_encode_bundle(pc, df, resource_name, input_type = NULL, column = NULL)
pc |
A Pathling context object. |
df |
A Spark DataFrame containing the bundles with the resources to encode. |
resource_name |
The name of the FHIR resource to extract (Condition, Observation, etc.). |
input_type |
The MIME type of the input string encoding. Defaults to 'application/fhir+json'. |
column |
The column in which the resources to encode are stored. If 'NULL', then the input DataFrame is assumed to have one column of type string. |
A Spark DataFrame containing the given type of resources encoded into Spark columns.
Other encoding functions:
pathling_encode()
pc <- pathling_connect()
json_resources_df <- pathling_spark(pc) %>%
sparklyr::spark_read_text(
path = system.file("extdata", "bundle-xml", package = "pathling"),
whole = TRUE
)
pc %>% pathling_encode_bundle(json_resources_df, "Condition",
input_type = MimeType$FHIR_XML, column = "contents"
)
pathling_disconnect(pc)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.