| tx_display | R Documentation |
Takes a Coding column as its input. Returns a Column that contains the canonical display name associated with the given code.
tx_display(coding, accept_language = NULL)
coding |
A Column containing a struct representation of a Coding. |
accept_language |
The optional language preferences for the returned display name.
Overrides the parameter 'accept_language' in |
A Column containing the result of the operation (String).
Pathling documentation - Multi-language support
Other terminology functions:
tx_member_of(),
tx_property_of(),
tx_subsumed_by(),
tx_subsumes(),
tx_translate()
## Not run:
# Get the display name of the first coding of the Condition resource, with the default language.
pc %>%
pathling_example_resource("Condition") %>%
sparklyr::mutate(
id,
display = !!tx_display(code[["coding"]][[0]]),
.keep = "none"
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.