| tx_subsumed_by | R Documentation |
Takes two Coding columns as input. Returns a Column that contains a Boolean value, indicating whether the left Coding is subsumed by the right Coding.
tx_subsumed_by(left_codings, right_codings)
left_codings |
A Column containing a struct representation of a Coding or an array of Codings. |
right_codings |
A Column containing a struct representation of a Coding or an array of Codings. |
A Column containing the result of the operation (boolean).
Pathling documentation - Subsumption testing
Other terminology functions:
tx_display(),
tx_member_of(),
tx_property_of(),
tx_subsumes(),
tx_translate()
pc <- pathling_connect()
# Test the codings of the Condition `code` for subsumption by a SNOMED CT code.
pc %>%
pathling_example_resource("Condition") %>%
sparklyr::mutate(
id,
is_subsumed_by = !!tx_subsumed_by(
code[["coding"]],
!!tx_to_snomed_coding("444814009")
),
.keep = "none"
)
pathling_disconnect(pc)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.